@@ -11,6 +11,8 @@ from django.template import loader, Context
 
 import click
 
+import yurl
+
 from aldryn_addons.utils import openfile, boolean_ish
 
 if six.PY2:
@@ -32,24 +34,14 @@ def web(ctx_obj):
     launch the webserver of choice (uwsgi)
     """
     if any(boolean_ish(ctx_obj['settings'][key]) for key in
-           ('ENABLE_NGINX', 'ENABLE_PAGESPEED', 'ENABLE_BROWSERCACHE')):
-        # uwsgi behind nginx. possibly with pagespeed/browsercache
+           ('ENABLE_NGINX', 'ENABLE_PAGESPEED')):
+        # uwsgi behind nginx. possibly with pagespeed
         start_with_nginx(ctx_obj['settings'])
     else:
         # pure uwsgi
         execute(start_uwsgi_command(settings=ctx_obj['settings'], port=80))
 
 
-@click.command()
-@click.pass_obj
-def worker(ctx_obj):
-    """
-    coming soon: launch the background worker
-    """
-    # TODO: celery worker startup, once available
-    pass
-
-
 @click.command()
 @click.pass_obj
 def migrate(ctx_obj):
@@ -90,7 +82,6 @@ def main(ctx, verbose):
 
 
 main.add_command(web)
-main.add_command(worker)
 main.add_command(migrate)
 
 
@@ -118,6 +109,25 @@ def execute(args, script=None):
     os.execvpe(command, args, get_env())
 
 
+def get_static_serving_args(base_url, root, header_patterns):
+    base_path = yurl.URL(base_url).path.lstrip('/')
+
+    args = [
+        '--static-map=/{}={}'.format(base_path, root),
+        '--route={} addheader:Vary: Accept-Encoding'.format(
+            os.path.join('^', base_path, '.*'),
+        ),
+    ]
+
+    for pattern, headers in header_patterns:
+        pattern = os.path.join('^', base_path, pattern)
+        for k, v in headers.items():
+            args.append('--route={} addheader:{}: {}'.format(pattern, k, v))
+        args.append('--route={} last:'.format(pattern, k, v))
+
+    return args
+
+
 def start_uwsgi_command(settings, port=None):
     cmd = [
         'uwsgi',
@@ -128,6 +138,7 @@ def start_uwsgi_command(settings, port=None):
         '--max-requests={}'.format(settings['DJANGO_WEB_MAX_REQUESTS']),
         '--harakiri={}'.format(settings['DJANGO_WEB_TIMEOUT']),
         '--lazy-apps',
+        '--honour-range',
     ]
 
     serve_static = False
@@ -135,46 +146,31 @@ def start_uwsgi_command(settings, port=None):
     if not settings['ENABLE_SYNCING']:
         if not settings['STATIC_URL_IS_ON_OTHER_DOMAIN']:
             serve_static = True
-            cmd.extend([
-                '--static-map={}={}'.format(
-                    settings['STATIC_URL'],
-                    settings['STATIC_ROOT'],
-                ),
-                # Set far-future expiration headers for django-compressor
-                # generated files
-                '--static-expires={} 31536000'.format(
-                    os.path.join(
-                        settings['STATIC_ROOT'],
-                        settings.get('COMPRESS_OUTPUT_DIR', 'CACHE'),
-                        '.*',
-                    )
-                ),
-                # Set far-future expiration headers for static files with
-                # hashed filenames
-                '--static-expires={} 31536000'.format(
-                    os.path.join(
-                        settings['STATIC_ROOT'],
-                        r'.*\.[0-9a-f]{10,16}\.[a-z]+',
-                    )
-                ),
-            ])
+            cmd.extend(get_static_serving_args(
+                settings['STATIC_URL'],
+                settings['STATIC_ROOT'],
+                settings['STATIC_HEADERS'],
+            ))
 
         if not settings['MEDIA_URL_IS_ON_OTHER_DOMAIN']:
             serve_static = True
-            cmd.append('--static-map={}={}'.format(
+            cmd.extend(get_static_serving_args(
                 settings['MEDIA_URL'],
                 settings['MEDIA_ROOT'],
+                settings['MEDIA_HEADERS'],
             ))
 
         if serve_static:
             cmd.extend([
                 # Start 2 offloading threads for each worker
                 '--offload-threads=2',
+
                 # Cache resolved paths for up to 1 day (limited to 5k entries
                 # of max 1kB size each)
                 '--static-cache-paths=86400',
                 '--static-cache-paths-name=staticpaths',
                 '--cache2=name=staticpaths,items=5000,blocksize=1k,purge_lru,ignore_full',
+
                 # Serve .gz files if that version is available
                 '--static-gzip-all',
             ])
